Interner

Struct Interner 

pub struct Interner<T> { /* private fields */ }

Implementations

Source

impl<T> Interner<T>

pub const fn new() -> Self

Creates an empty Interner. The current implementation does not allocate

pub fn len(&self) -> usize

Returns the number of entries in the interner

pub fn is_empty(&self) -> bool

Returns true if the interner contains no elements

pub fn insert_arena(&self, value: T) -> &mut T

Source

impl<T: Hash + Eq> Interner<T>

pub fn try_resolve<Q>(&self, value: &Q) -> Option<&T>
where T: Borrow<Q>, Q: ?Sized + Hash + Eq,

Will return a reference to an equivalent value if it already exists

pub fn intern(&self, value: T) -> &T

Returns a reference to either the value provided, or an equivalent value that was already inserted

pub fn intern_new(&self, value: T) -> &T

Inserts the value into the interner without checking if the value already exists

pub fn intern_ref_unique(&self, value: &'static T)

Inserts a reference to the value into the interner. All future calls the Interner::intern will return the provided reference.

This function will not check if an equivalent value already exists within the table, and may behave weirdly if one does.